@@ -1,5 +1,5 @@
 class ConfigError(Exception):
-    MESSAGE = "Wrong parameters inside config ini file"
+    MESSAGE = "Wrong parameters were provided"
 
     def __init__(self, message: str = MESSAGE):
         super().__init__(message)
